import sys

__warning_shown = False

if not __warning_shown:
    sys.stderr.write("'oelint_adv.cls_item' is deprecated. Please use 'oelint_parser.cls_item' instead\n")
    __warning_shown = True

# provide aliases for legacy imports
from oelint_parser.cls_item import Comment as Comment
from oelint_parser.cls_item import Include as Include
from oelint_parser.cls_item import Item as Item
from oelint_parser.cls_item import MissingFile as MissingFile
from oelint_parser.cls_item import PythonBlock as PythonBlock
from oelint_parser.cls_item import TaskAdd as TaskAdd
from oelint_parser.cls_item import TaskAssignment as TaskAssignment
from oelint_parser.cls_item import Variable as Variable



import sys

__warning_shown = False

if not __warning_shown:
    sys.stderr.write("'oelint_adv.helper_files' is deprecated. Please use 'oelint_parser.helper_files' instead\n")
    __warning_shown = True

# provide aliases for legacy imports
from oelint_parser.helper_files import expand_term as expand_term
from oelint_parser.helper_files import find_local_or_in_layer as find_local_or_in_layer
from oelint_parser.helper_files import get_files as get_files
from oelint_parser.helper_files import get_known_mirrors as get_known_mirrors
from oelint_parser.helper_files import get_layer_root as get_layer_root
from oelint_parser.helper_files import get_scr_components as get_scr_components
from oelint_parser.helper_files import get_valid_named_resources as get_valid_named_resources
from oelint_parser.helper_files import get_valid_package_names as get_valid_package_names
from oelint_parser.helper_files import guess_base_recipe_name as guess_base_recipe_name
from oelint_parser.helper_files import guess_recipe_name as guess_recipe_name
from oelint_parser.helper_files import guess_recipe_version as guess_recipe_version
from oelint_parser.helper_files import safe_linesplit as safe_linesplit



import sys

__warning_shown = False

if not __warning_shown:
    sys.stderr.write("'oelint_adv.const_vars' is deprecated. Please use 'oelint_parser.const_vars' instead\n")
    __warning_shown = True

# provide aliases for legacy imports
from oelint_parser.const_vars import get_base_varset as get_base_varset
from oelint_parser.const_vars import get_constantfile as get_constantfile
from oelint_parser.const_vars import get_known_machines as get_known_machines
from oelint_parser.const_vars import get_known_mirrors as get_known_mirrors
from oelint_parser.const_vars import get_known_vars as get_known_vars
from oelint_parser.const_vars import get_mandatory_vars as get_mandatory_vars
from oelint_parser.const_vars import get_protected_append_vars as get_protected_append_vars
from oelint_parser.const_vars import get_protected_vars as get_protected_vars
from oelint_parser.const_vars import get_rulefile as get_rulefile
from oelint_parser.const_vars import get_suggested_vars as get_suggested_vars
from oelint_parser.const_vars import KNOWN_MACHINES as KNOWN_MACHINES
from oelint_parser.const_vars import KNOWN_MIRRORS as KNOWN_MIRRORS
from oelint_parser.const_vars import KNOWN_VARS as KNOWN_VARS
from oelint_parser.const_vars import MANDATORY_VARS as MANDATORY_VARS
from oelint_parser.const_vars import SUGGESTED_VARS as SUGGESTED_VARS
from oelint_parser.const_vars import VAR_ORDER as VAR_ORDER
from oelint_parser.const_vars import VAR_PROTECTED as VAR_PROTECTED
from oelint_parser.const_vars import VAR_PROTECTED_APPEND as VAR_PROTECTED_APPEND



import sys

__warning_shown = False

if not __warning_shown:
    sys.stderr.write("'oelint_adv.parser' is deprecated. Please use 'oelint_parser.parser' instead\n")
    __warning_shown = True

# provide aliases for legacy imports
from oelint_parser.parser import INLINE_BLOCK as INLINE_BLOCK



import sys

__warning_shown = False

if not __warning_shown:
    sys.stderr.write("'oelint_adv.const_func' is deprecated. Please use 'oelint_parser.const_func' instead\n")
    __warning_shown = True

# provide aliases for legacy imports
from oelint_parser.const_func import FUNC_ORDER as FUNC_ORDER
from oelint_parser.const_func import KNOWN_FUNCS as KNOWN_FUNCS
